package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````\"4```````!``````````#BQ````
M`````````$``.``+`$``&P`:``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````'`:````````<!H`````````
M$`````````$````%`````"``````````(``````````@````````E3P`````
M``"5/``````````0`````````0````0`````8`````````!@`````````&``
M```````(10````````A%`````````!`````````!````!@```+BK````````
MN+L```````"XNP```````&@$````````$!4`````````$`````````(````&
M````R*L```````#(NP```````,B[````````$`(````````0`@````````@`
M````````!`````0```#$`@```````,0"````````Q`(```````!$````````
M`$0`````````!`````````!0Y71D!````("=````````@)T```````"`G0``
M``````0!````````!`$````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``"XJP```````+B[````````N+L```````!(!````````$@$`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!0````#````
M1TY5`,-&2`4S@!AQZLQKE%"!<*#`#P9>!````!`````!````1TY5```````#
M`````@`````````1````0@````0````(````(!P0``5`!(8H`D`$D(8`A(()
M`"!)(`0(N*(11;H``@H`````0@```$4```!(````20```%````!1````4P``
M`%<```!8````6@```%L```!>````8````&(``````````````&[%WQ_.WD<M
M:W^:?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGS[
MH6Q@:PE#UF:OS&;%N9Q`./*+',2)!9!"1=7LB0=PTPT4XIXR8MOMV\WCGA6,
M)<P,.I<+5J2;EJ?=HVM^J9R;T67.;>"G`@IK&IY0"HH05Z/@^TD`````````
M````````````````````````````]P$``!(`````````````````````````
M#`$``!(`````````````````````````DP```!(`````````````````````
M````E@(``!(`````````````````````````S`$``!(`````````````````
M````````DP$``!(`````````````````````````40(``!(`````````````
M````````````@0(``!(`````````````````````````(@$``!(`````````
M````````````````$0```"``````````````````````````%0(``!(`````
M````````````````````.`,``!(`````````````````````````V@$``!(`
M````````````````````````&@(``!(`````````````````````````J@$`
M`!(`````````````````````````'`,``!(`````````````````````````
M4P$``!(`````````````````````````M````!(`````````````````````
M````0P$``!(`````````````````````````/`(``!(`````````````````
M````````>P(``!(`````````````````````````-0$``!(`````````````
M````````````6`(``!(`````````````````````````V@,``!(`````````
M````````````````(````"``````````````````````````L0$``!(`````
M````````````````````$0$``!(`````````````````````````;0(``!(`
M````````````````````````/````"``````````````````````````KP(`
M`!(`````````````````````````5@```!(`````````````````````````
M@P$``!(`````````````````````````<P```!(`````````````````````
M````\````!(`````````````````````````A````!(`````````````````
M````````WP$``!(`````````````````````````=`(``!(`````````````
M````````````U````!(`````````````````````````SP(``!(`````````
M````````````````=0$``!(`````````````````````````!@,``!(`````
M````````````````````V`(``!(`````````````````````````I`(``!(`
M````````````````````````9P$``!(`````````````````````````Y@$`
M`!(`````````````````````````7P(``!(`````````````````````````
M%@$``!(`````````````````````````*P(``!(`````````````````````
M````%0,``!(`````````````````````````9@(``!(`````````````````
M````````R`(``!(`````````````````````````GP```!(`````````````
M````````````MP(``!(`````````````````````````G@$``!(`````````
M````````````````T@$``!(`````````````````````````(@(``!(`````
M````````````````````^`(``!(`````````````````````````#@,``!(`
M````````````````````````20(``!(`````````````````````````7`$`
M`!(`````````````````````````9````!(`````````````````````````
MCP(``!(`````````````````````````WP(``!(`````````````````````
M````0P(``!(`````````````````````````P@```!(`````````````````
M````````XP,``!(`#@#`0````````'<`````````2`0``!(`#@`0-0``````
M`,4'````````*0,``!(`#@#@(P````````0"````````2@,``!(`#@"@+@``
M``````4`````````>`,``!(`#@#@/````````-D#````````;@0``!(`#@"P
M+@```````/(!````````+@0``!``&``@P```````````````````6P,``!(`
M#@"P,````````"4`````````C@,``!(`#@"0,P```````'0`````````[P,`
M`!$`$```8`````````0`````````"P0``!(`#@!P6````````)\!````````
M%@0``!(`#@!@+0```````#``````````0P0``!``&`#(T```````````````
M````7`0``!(`#@`P-````````-X`````````_@,``!``%P``P```````````
M````````L@,``!(`#@#@,````````-P`````````+@,``!$`&`!`P```````
M``@`````````P0(``!$`&`!@P`````````@`````````+P,``"$`&`!`P```
M``````@`````````500``!``%P`@P```````````````````>P0``!$`%P`8
MP`````````@`````````:`,``!(`#@!P7`````````$`````````!`0``!(`
M#@#P)0```````"L`````````'@0``!(`#@`07````````%T`````````.@0`
M`!(`#@`06````````%0```````````0``"``%P``P```````````````````
M`0$``!$`&``@P`````````0`````````,`,``"$`&`!`P`````````@`````
M````R`,``!(`#@`0-````````!T`````````Z0(``"(`````````````````
M````````G`,``!(`#@#@+0```````+\`````````O@,``!(`#@`06@``````
M`/L!````````XP```!$`&`"`P`````````$`````````A00``!(`#@#`,0``
M`````,X!`````````&QI8G!E<FPN<V\N-2XS,`!?7V=M;VY?<W1A<G1?7P!?
M251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F
M;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!0
M97)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!0
M3%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U
M;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`
M4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$
M>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?
M86QL;V,`;&EB<'1H<F5A9"YS;RXP`&-L;W-E`&QS965K-C0`<F5A9`!O<&5N
M-C0`7U]E<G)N;U]L;V-A=&EO;@!P=&AR96%D7V=E='-P96-I9FEC`&QI8F,N
M<V\N-@!E>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U
M;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T
M;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?
M7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D
M97)R`&=E='5I9`!R96%D;&EN:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I
M;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?
M;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!P
M87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`
M6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E
M;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA
M;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?
M7V1A=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?;&EB8U]C<W5?:6YI
M=`!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A
M=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P
M87)?:6YI=%]E;G8`1TQ)0D-?,BXQ-`!'3$E"0U\R+C0`1TQ)0D-?,BXS+C(`
M1TQ)0D-?,BXR+C4`1TQ)0D-?,BXS+C0``````@```````P`"````!``#````
M```$``4``@`$``0`!``````````$``0````$``0```````0`!`````0`````
M``````````(`!`````0````$``0`!`````(`!`````8`!``$``0````$````
M`@`$``,`!``$```````'``0`!`````$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$`!``$``0``0`!``$``0`!``$``0````0``0`$``$``0````$`
M``````$`!0`+`@``$````&````"4D98&```'`)($```0````%&EI#0``!@"=
M!```$````'(9:0D```4`IP0``!````!U&FD)```$`+,$```0````=!EI"0``
M`P"_!`````````$``0"\`0``$`````````!U&FD)```"`+,$````````N+L`
M```````(`````````-`F````````P+L````````(`````````)`F````````
M",`````````(``````````C`````````&,`````````(`````````.AB````
M````P+\````````&````"0``````````````R+\````````&````"@``````
M````````T+\````````&````$```````````````V+\````````&````&0``
M````````````X+\````````&````'0``````````````Z+\````````&````
M7P``````````````\+\````````&````(```````````````^+\````````&
M````(0``````````````(,`````````%````7```````````````0,``````
M```%````4@``````````````8,`````````%````4P``````````````@,``
M```````%````8@``````````````\+T````````'`````0``````````````
M^+T````````'`````@```````````````+X````````'`````P``````````
M````"+X````````'````!```````````````$+X````````'````!0``````
M````````&+X````````'````!@``````````````(+X````````'````!P``
M````````````*+X````````'````"```````````````,+X````````'````
M"P``````````````.+X````````'````#```````````````0+X````````'
M````#0``````````````2+X````````'````#@``````````````4+X`````
M```'````#P``````````````6+X````````'````$0``````````````8+X`
M```````'````$@``````````````:+X````````'````$P``````````````
M<+X````````'````%```````````````>+X````````'````%0``````````
M````@+X````````'````%@``````````````B+X````````'````%P``````
M````````D+X````````'````&```````````````F+X````````'````&@``
M````````````H+X````````'````&P``````````````J+X````````'````
M'```````````````L+X````````'````'@``````````````N+X````````'
M````'P``````````````P+X````````'````(@``````````````R+X`````
M```'````(P``````````````T+X````````'````)```````````````V+X`
M```````'````)0``````````````X+X````````'````)@``````````````
MZ+X````````'````)P``````````````\+X````````'````*```````````
M````^+X````````'````*0```````````````+\````````'````*@``````
M````````"+\````````'````*P``````````````$+\````````'````+```
M````````````&+\````````'````+0``````````````(+\````````'````
M+@``````````````*+\````````'````+P``````````````,+\````````'
M````,```````````````.+\````````'````,0``````````````0+\`````
M```'````,@``````````````2+\````````'````,P``````````````4+\`
M```````'````-```````````````6+\````````'````-0``````````````
M8+\````````'````-@``````````````:+\````````'````-P``````````
M````<+\````````'````.```````````````>+\````````'````.0``````
M````````@+\````````'````.@``````````````B+\````````'````.P``
M````````````D+\````````'````/```````````````F+\````````'````
M/0``````````````H+\````````'````/@``````````````J+\````````'
M````/P``````````````L+\````````'````0```````````````N+\`````
M```'````00``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%O9\``$B%P'0"_]!(@\0(PP```````````/\UNIT``/\EO)T`
M``\?0`#_);J=``!H`````.G@_____R6RG0``:`$```#IT/____\EJIT``&@"
M````Z<#_____):*=``!H`P```.FP_____R6:G0``:`0```#IH/____\EDIT`
M`&@%````Z9#_____)8J=``!H!@```.F`_____R6"G0``:`<```#I</____\E
M>IT``&@(````Z6#_____)7*=``!H"0```.E0_____R5JG0``:`H```#I0/__
M__\E8IT``&@+````Z3#_____)5J=``!H#````.D@_____R52G0``:`T```#I
M$/____\E2IT``&@.````Z0#_____)4*=``!H#P```.GP_O___R4ZG0``:!``
M``#IX/[___\E,IT``&@1````Z=#^____)2J=``!H$@```.G`_O___R4BG0``
M:!,```#IL/[___\E&IT``&@4````Z:#^____)1*=``!H%0```.F0_O___R4*
MG0``:!8```#I@/[___\E`IT``&@7````Z7#^____)?J<``!H&````.E@_O__
M_R7RG```:!D```#I4/[___\EZIP``&@:````Z4#^____)>*<``!H&P```.DP
M_O___R7:G```:!P```#I(/[___\ETIP``&@=````Z1#^____)<J<``!H'@``
M`.D`_O___R7"G```:!\```#I\/W___\ENIP``&@@````Z>#]____);*<``!H
M(0```.G0_?___R6JG```:"(```#IP/W___\EHIP``&@C````Z;#]____)9J<
M``!H)````.F@_?___R62G```:"4```#ID/W___\EBIP``&@F````Z8#]____
M)8*<``!H)P```.EP_?___R5ZG```:"@```#I8/W___\E<IP``&@I````Z5#]
M____)6J<``!H*@```.E`_?___R5BG```:"L```#I,/W___\E6IP``&@L````
MZ2#]____)5*<``!H+0```.D0_?___R5*G```:"X```#I`/W___\E0IP``&@O
M````Z?#\____)3J<``!H,````.G@_/___R4RG```:#$```#IT/S___\E*IP`
M`&@R````Z<#\____)2*<``!H,P```.FP_/___R4:G```:#0```#IH/S___\E
M$IP``&@U````Z9#\____)0J<``!H-@```.F`_/___R4"G```:#<```#I</S_
M__\E^IL``&@X````Z6#\____)?*;``!H.0```.E0_/___R42G```9I``````
M`````$%454B#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E
M*````$B)1"0H,<#H9____TB+-:";``!(BSW1FP``2(GRZ%$X``"`/4J<````
M=2_H0_W__TB)!7RL``!(B<=(A<`/A(H!``#HB_W__XL]Q9L``.C0^___QH#1
M"0```(L]LYL``.B^^___BSVHFP``@(@Z!````NBL^___@(@Z!````8M$)!R-
M>`5(8_](P><#Z'+^__],BTPD$(M4)!S'!?^K```$````2(G!2(D%[:L``$F+
M`4B)`4B-!0P]``!(B4$(2(L%19L``$B)01!(C07Y/```2(E!&(/Z`7XI1(U"
M_KX!````28/``@\?0`!)BP3QC7X$2(/&`4AC_TB)1/GX23GP=>B-0@1%,<"#
MP@-(BSV@JP``2)A(C35G"```2,=$P?@`````Z$G[__]!B<2%P'132(L]>ZL`
M`$B-;"0DZ"']__\QP$B)[DB-/4D[``#H@`$``$B%P'0]2(L]5*L``.C/^O__
MZ$K\__](BT0D*&1(,P0E*````'5/2(/$.$2)X%U!7,-(BSTHJP``Z&/[__]!
MB<3KG$B+/0^K``!(A?]T!^@-&P``Z[!(C3V=.@``2(GNZ!P!``!(B07MJ@``
M2(G'2(7`=)+KV>C6_/__OP$```#HS/K__V8N#Q^$``````!FD#'M28G17DB)
MXDB#Y/!05$R-!6HV``!(C0T#-@``2(T]S/W___\5MID``/0/'T0``$B-/?F9
M``!(C07RF0``2#GX=!5(BP6>F0``2(7`=`G_X`\?@`````###Q^``````$B-
M/<F9``!(C37"F0``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!669``!(A<!T
M"/_@9@\?1```PP\?@`````"`/>J9````=2]52(,]1ID```!(B>5T#$B+/5J9
M``#H'?W__^AH____Q@7"F0```5W##Q^``````,,/'X``````Z7O___]F+@\?
MA```````D$%7059!54%455-(@^P(2(7_#X2Q````3(LU0ID``$V%]@^$H0``
M``^V!TF)_TB)]83`=`0\/75813'M38LF387D=#--8^U,B?,/'X``````3(GJ
M3(G^3(GGZ*+Y__^%P'4'0X`\+#UT1TR+8PA(@\,(387D==I(@\0(3(G@6UU!
M7$%=05Y!7\,/'X0``````$F)_4$/MD4!28/%`83`=`0\/77O12G]ZY(/'X``
M````3"GS3XUD+`%(P?L#B5T`Z[4/'X``````13'DZZD/'P!54TB)^TB#[!AD
M2(L$)2@```!(B40D"#'`2(UL)`1FD#'`2(GN2(G?Z`/___](A<!T-DAC5"0$
M2(L%4I@``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/
M'T0``$B+1"0(9$@S!"4H````=0=(@\086UW#Z'SZ__]F9BX/'X0``````)!!
M5T%6055!5%5(B?532(G[2(/L*&1(BP0E*````$B)1"08,<`QP(`^/0^4P$@!
MQ4B)[^@I^?__2(UT)!1(B=])B<0QP.A7_O__2(7`#X0.`0``2(G'28G%Z`/Y
M__],.>`/@]H```!,8W0D%$G!Y@,/M@.$P`^$K@$``#P]#X2F`0``2(G8#Q\`
M#[90`4B#P`&$TG0%@/H]=>](*=A(F$J-?"`"3`,U5I<``.@!^/__28D&2(7`
M#X2&`0``2(L%/I<``$AC5"042(U+`4B+%-`/M@.(`CP]=!V$P'4(ZQ=FD#P]
M=!$/M@%(@\(!2(/!`8@"A,!UZ\8"/3'`9@\?1```#[9,!0"(3`(!2(/``83)
M=>\QP$B+7"089$@S'"4H````#X45`0``2(/$*%M=05Q!74%>05_#9BX/'X0`
M`````#'`9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[4/'T``3(L]F98``$F#
M/P`/A+X```!,B?A%,>UF#Q^$``````!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC
M]DC!Y@.+!;^F``"%P'5;QP6QI@```0```$B)]^CY]O__2(7`#X2!````36/%
M3(G^2(G'3HTTQ0````!,B40D"$R)\N@B^/__3(M$)`A(B046E@``2(G!2L=$
MP0@`````1(EL)!3I;_[__TR)_^@8^?__2(D%\94``$B)P4B%P'0J36/%3HTT
MQ0````#KR0\?0``QP.EO_O__OA````!%,>WI7____^@O^/__@\C_Z<K^__\/
M'X``````059!54%455-(@>R@````9$B+!"4H````2(F$))@````QP$B%_W0(
M@#\`2(G]=3%(BX0DF````&1(,P0E*`````^%$0$``$B!Q*````!;74%<05U!
M7L-F+@\?A```````Z+OV__])B<1(A<!TPDB)XTR)Y^B8^/__2(7`#X2G````
M9H-X$RY,C7`3=.1F@7@3+BX/A*@```!(B>_H</;__TR)]TF)Q>AE]O__08U\
M!0)(8__HJ/7__TV)\4F)Z+X!````28G%2(G',<!(Q\+_____2(T-GC0``.C2
M]___OP$```!(B=I,B>[H@O?__TR)[X/X_W00BT0D&"4`\```/0!```!T2NB5
M]?__3(GOZ.WU__],B>?H]??__TB%P`^%7?___P\?0`!,B>?H</?__TB)[^AX
M]?__Z?+^__\/'P!!@'X"``^$)?___^E(____Z*O^___KM.C$]O__#Q]``%5(
MB?Y(B?V_`0```$B![*````!D2(L$)2@```!(B80DF````#'`2(GBZ$+V__^%
MP'4VBU0D&('B`/```('Z`$```'0(@?H`H```=1Z^`@```$B)[^@']___A<`/
ME,`/ML#K!P\?1```,<!(BXPDF````&1(,PPE*````'4)2('$H````%W#Z#7V
M__\/'T0``$%7NO\/``!!5D%5051)B?152(G]2(T]<C,``$B![!`0``!D2(L$
M)2@```!(B80D"!```#'`28GE3(GNZ&#U__^%P'YTC5#_1(L]4I,``$QC\D*`
M/#0`=5B%TG1C3(GROB\```!,B>_HI//__TB%P'1.1(G_Z#?S__],B?%,B>I(
MB>Y(B<?H!O7__TB+A"0($```9$@S!"4H````=3I(@<00$```74%<05U!7D%?
MPV:03&/PZZ</'P!$BSWAD@``1(G_Z.GR__],B>)(B>Y(B<?H^_/__^NSZ%3U
M__\/'T``2(/L"(L]MI(``.C!\O__2(L5>I(``$B#Q`A(C0W/;P``2(G'2(TU
MD3(``.G@]?__2(/L"(L]AI(``.B1\O__2(G'Z+G___^+/7.2``#H?O+__TR-
M!?@S``!%,<E(C14=#P``2(G'3(G!2(TU:#(``$B#Q`CI]_/__P\?@`````!!
M5%532('L("```&1(BP0E*````$B)A"08(```,<!(B>5,C:0D$!```.A2\___
M3(T-`S(``+H!$```2(GO08G`2(T-)C(``+X!````,<#H#?7__[H`$```3(GF
M2(GOZ-WS__]%,<"%P'@NC7@!2(G#2&/_Z)CR__])B<!(A<!T&$ACVTR)YDB)
MQTB)VN@?]?__Q@08`$F)P$B+A"08(```9$@S!"4H````=0](@<0@(```3(G`
M6UU!7,/H$?3__Y#I.____V9F+@\?A```````05=!5DF)]D%5051)B?Q(C3V4
M,0``55-(@>RX$```9$B+!"4H````2(F$)*@0```QP$B-="0,Z/7W__^^+P``
M`$R)YTB)Q>A5\___2(7`=$!,B>9(C3U8,0``,<#H+_G__TR)X$B+C"2H$```
M9$@S#"4H````#X5R`0``2('$N!```%M=05Q!74%>05_##Q\`3(GGZ%CR__](
MC34@,0``3(GW08G%Z';S__](B<-(A<!TGH`[`$R--9DP```/A-4```!F#Q]$
M``!(A>UT$TB)WDB)[^@X\___A<`/A)0```!(B=_H"/+__XG"2)B`?`/_+W46
M#Q]$``"#Z@%(8\*`?`/_+\8$`P!T[T&-1!4!/?\/```/CS?___])B=BZ`!``
M`+X!````,<!,C;PDH````$B#[`A(C0U\,0``051,C0U],```3(G_Z$3S__](
MC50D($R)_K\!````Z/+R__]:687`=1"+1"0H)0#P```]`(```'1,2(TU1#``
M`#'_Z)[R__](B<-(A<`/A,+^__^`.P`/A3'___](A>UT!H!]`"YT#DR)\[H!
M````Z5K___^0@'T!`'2^Z^H/'X0``````+X!````3(G_Z-/R__^%P'6C3(G^
M2(T]UR\``.BP]___3(G_Z/CQ___I=_[__^@.\O__9F8N#Q^$```````/'P`/
MM@=)B?B$P'079@\?1```2(/'`3PO#[8'3`]$QX3`=>],B<##9F8N#Q^$````
M``!(A?\/A,<```!5@#\`2(G]#X2B````Z*7P__](C50%_T@YU7(4Z9L```!F
M#Q]$``!(@^H!2#G5="6`.B]T\D@YU0^#?@```$B#Z@%(.=5T#H`Z+W0@2(/J
M`4@YU77R@#HO=%5(C3TG+P``7>E`\?__@#HO=0E(@^H!2#G5<O)(*>HQP$B-
M2@)(@?D`$```=Q](@\(!N0`0``!(B>Y(C3T=CP``Z-CN__](C041CP``7<,/
M'X``````2(T]9BX``%WIZ_#__T@YU76KZY(/'T``2(T]3BX``.G4\/__#Q]`
M`%4QTDB-/:DN``!(@^Q`9@]O!8IK``!D2(L$)2@```!(B40D.#'`9HE4)#!(
MC6PD#`\I1"009@]O!7-K```/*40D(.BI]?__,<!(C3UL+@``Z)OU__\QP$B-
M/68N``#HC?7__S'`2(T]82X``.A_]?__,<!(C3U:+@``Z''U__\QP$B-/5PN
M``#H8_7__S'`2(T]`RX``.A5]?__,<!(C3U,+@``Z$?U__\QP$B-/4@N``#H
M.?7__S'`2(T]1"X``.@K]?__,<!(C3W4+0``Z!WU__\QP$B)[DB-/2\N``#H
M//3__TB%P'012(G&2(T]!RX``#'`Z(;U__](B>Y(C3T;+@``,<#H%?3__TB)
MQDB%P'0.2(T]%RX``#'`Z%_U__](B>Y(C3T1+@``,<#H[O/__TB)QDB%P'0^
M2(T]6"T``#'`Z#CU__\QP$B--1<N``!(C3U\+0``Z"/U__](BT0D.&1(,P0E
M*````'5<2(/$0%W##Q]$``!(B>Y(C3W*+0``,<#HE_/__TB)QDB%P'072(T]
M6"T``#'`Z.'T___KIP\?@`````!(N%!!4E]#3$5!2#E$)"%UCV:!?"0I3CUU
MADB-="0KZ\CH(N___V:02(/L&&1(BP0E*````$B)1"0(,<"+!6:,``"#^/]T
M&4B+?"0(9$@S/"4H````=4!(@\08PP\?0`!(C70D!$B-/=PL```QP.@%\___
M2(G",<!(A=)T$@^V$H#Z,`^5P3'`A-(/E<`AR(D%$XP``.NPZ*SN__]F9BX/
M'X0``````)!(@^P(Z,?N__^)Q^A0[?__2(7`=`-(BP!(@\0(PP\?`$%454B)
M_4B-/>TL``!32(/L$&1(BP0E*````$B)1"0(,<!(C70D!.B$\O__2(GN2(7`
M=`B`.`!(B<-U+$B-/;<L```QP.C&\___2(M$)`AD2#,$)2@```!U?TB#Q!!;
M74%<PP\?1```2(G'Z&#M__](A<!UU4B)[^CS[/__2(G?28G$Z.CL__])C7P$
M`N@N[/__2(/L"$F)Z+X!````4TC'PO____](B<=)B<1,C0V,*P``2(T-?2P`
M`#'`Z$_N__],B>9(C3TO+```,<#H/O/__UA:Z7'____HHNW__V:005=!5D%5
M28G]2(T].2L``$%455-(@>R(@0``9$B+!"4H````2(F$)'B!```QP$B-!0$L
M``!,C60D'$C'1"0P`````$B)1"0@2(T%IBH``$R)YDB)1"0H2(T%?"L``$B)
M1"1H2(T%T2L``$B)1"1P2(T%@2L``$B)1"1X2(T%P2L``$B)A"2`````2(T%
MMBL``$B)1"1(,<!(QX0DB`````````!(QT0D4`````#H'O'__TB%P'0,@#@`
M2(G%#X7]!```,<#H-O[__TB)Q4B%P`^$2@0``$B)[^BRZ___2(U\``'H^.K_
M_T0/MD4`2(G#183`=#9)B=],C351*P``D$R)_TR)\4C'PO____\QP+X!````
M2(/%`4F#QP+H#^W__T0/MD4`183`==5,C70D8$B-/:HJ``#K&`\?@`````!)
MBWX(28/&"$B%_P^$EP$``$R)YC'`Z'7P__](B<5(A<!TW8`X`'382(G'Z'#U
M__^%P'3,2(GOZ`3L__])B<=(A<`/A&`!```/'X0``````$R)^8L12(/!!(V"
M__[^_O?2(=`E@("`@'3IB<+!ZA"I@(````]$PDB-40)(#T3*B<(`PDB)VDB#
MV0-,*?F+,DB#P@2-AO_^_O[WUB'P)8"`@(!TZ8G&P>X0J8"````/1,9(C7("
M2`]$UHG&0`#&2(/:`T@IVD2-M!$$!```36/V3(GWZ,CI__]338GX3(T-/BD`
M`$B)Q4B-!3$J``"^`0```$C'PO____]02(T-%"H``$B)[S'`Z.7K__](B>^^
MP`$``.A([/__7T%8@_C_=1+H"^O__T2+"$&#^1$/A2(#``!(C90DD````$B)
M[K\!````Z,GJ__^)PX7`#X2_````28M-`$B+/;2(``!)B>@QP$B-%6@J``"^
M`0```$4Q]NC;Z/__2(N$)'B!``!D2#,$)2@````/A?0$``!(@<2(@0``3(GP
M6UU!7$%=05Y!7\,/'X``````2(ML)"!%,?;K$V8/'T0``$ECQDB+;,0@2(7M
M=#N`?0``=#5(B>]!@\8!Z,GS__^%P'3=2(GOZ%WJ__])B<=(A<`/A6'^__])
M8\9(BVS$($B%[77)#Q]``$4Q_^E(_O__#Q^$``````"+A"2H````)0#P```]
M`$````^%*O___T2+O"2L````Z%SJ__]!.<</A13___^+A"2H````)?\!```]
MP`$```^%_?[__TR)]^A$Z/__2(T]@B@``$R)YDF)QC'`Z"#N__](B<=(A<`/
MA"0"``#HO^G__TF+?0!(B<;HT_7__TF)Q$B%P`^$!P(``$R)Y^BOZ/__@_@#
M?CI(8]"Y!0```$B-/6XH``!)C704_/.F#Y?"@-H`A-)U&H/X!`^$!0,``(/H
M!$B808!\!/\O#X3T`@``,<#H6?K__X7`=15,B><Q]NBKZ/__08G$A<`/A:D!
M``!(C371)P``2(T]4B<``#'`Z-ON__],C25%*```3(TM_B8``.CHY___051)
MB>B^`0```%!(Q\+_____3(GW,<!,C0W;)@``2(T-[R<``.B>Z?__6%KK2V8N
M#Q^$``````#HR^C__X,X$75)Z*'G__^#PP%(@^P(38GI051)B>A(C0W%)P``
M3(GW4TC'PO____^^`0```%`QP.A3Z?__2(/$(+[``0``3(GWZ++I__^#^/]T
MK4B)[^B%Y___3(GV2(T]1"8``#'`Z"3N__],B??H#/K__^F<_?__#Q^`````
M`#';2(T]`2<``.L2#Q]$``!(8\-(BWS$0$B%_W0X3(GF,<"#PP'HANS__TB%
MP'3A@#@`=-Q(B<?H).C__TB)Q4B%P`^%;OO__TACPTB+?,1`2(7_=<B_#0``
M`$B-+:XF``#H6N;__T&X4P```$B)P^EA^___28M-`$B+/;&%``!)B>@QP$B-
M%24G``"^`0```$4Q]NC8Y?__Z?C\__\/'P!(B<?H6/G__TB)[^BPY___28G&
MZ=W\__\/'X0``````$V+90#I\/W__[H"````2,?&[O___XG'Z!3H__](C9PD
M<`$``+H&````1(GG2(G>Z*SE__^`O"1P`0```'4.@+PD<0$``$,/A"H!```Q
MTC'V1(GGZ-CG__\QP.C!'```28G%ZQ$/'T``B<)(B=Y,B>_H"QT``+H`@```
M2(G>1(GGZ%OE__^%P'_?1(GG3(V\)"`!``!,C275)0``Z.#D__],B>Y,B?],
MC:PD:`$``.AM'@``2(V$)$`!``!(B40D"$B)PP\?1```10^V!TB)WTR)X;X!
M````2,?"_____S'`2(/#`DF#QP'H8^?__TDYW7762(T%R"4``,:$)&@!````
M4/]T)!!(C0V`)0``28GH3(GW,<"^`0```$R-#6`D``!(Q\+_____Z"/G__]9
M7NG?_?__38MM"$V%[0^$__S__TR)[^AGY?__2(/X`P^&[?S__TF-=`7\N04`
M``!(C3TD)0``\Z8/E\`<`(3`30]$Y>G*_/__@+PD<@$``$$/A<C^__^`O"1S
M`0``0P^%NO[__X"\)'0!``!(#X6L_O__@+PD=0$``$4/A9[^__^Z`@```$C'
MQL;___]$B>?H;N;__[HI````2(G>1(GGZ`[D__](C07H)```4%/I)O___^C;
MY?__9F8N#Q^$``````!!5T%6055!5%532(/L&(L]+(,``&1(BP0E*````$B)
M1"0(,<!,C6PD!.@BX___BST,@P``2(G#Z!3C__\/MI.X````3(GN2(T]9R,`
M`(B0N0```#'`Z*;I__](A<!T"8`X,0^$^`(``#'`Z''T__^+/<N"``#HUN+_
M_[D+````N@$```!(C35`)```2(G'Z*WC__]$BS6F@@``2(7`#X3-````2(M`
M$(,](I,```%,BV`H#XZX````,=OK-@\?0`!)BW<02(L%_9(``$ACU4B+/-#H
M">7__T&)P(L%\)(``$6%P`^%?````(/#`CG#B>M]<T2)]XUK`>A3XO__,<E(
M8]-,B>9(B<?H0^3__TB%P'1&3(LX1(LU)((``$&+1PPE``0@`#T`!```=)1$
MB??H'.+__TR)_KD"````,=)(B<?HFN7__T2+-?.!``!(B<;I;____P\?`(L%
M<I(``$2+-=N!``"-4/\YV@^$@`$``$2)]^C8X?__N0,```"Z`0```$B--4<C
M``!(B<?HK^+__TB)PTB%P'0U2(M`$(L]G8$``$B+*.BEX?__2(T5(",``$B)
MQTB)[NBSXO__2(M#$$B+*/9%#D`/A<X!``"+/6R!``#H=^'__[D#````N@$`
M``!(C37M(@``2(G'Z$[B__](B<-(A<!T/4R)[DB-/7XA```QP.CUY___28G$
M2(7`#X19`0``2(M#$(L]'X$``$B+*.@GX?__3(GB2(G'2(GNZ#GB__^+/0.!
M``#H#N'__[H!````2(TUBR(``$B)Q^@:X?__BSWD@```2(G%Z.S@__](C16#
M(@``2(GN2(G'Z/KA__^+/<2```#HS^#__TR)[DB-/>X@``#&@+D`````,<#H
M9^?__TB)!3B1``!)B<1(A<`/A(0```"^P`$``$R)Y^@7Y/__C5`!@_H!=@F#
M^!$/A?(```!(BT0D"&1(,P0E*`````^%V0```$B#Q!A;74%<05U!7D%?PP\?
M`(/X`0^.=_[__[L!````9I!$B?>#PP'H1>#__TR)YDB)Q^@:X?__.1VTD```
M1(LU'8```'_;Z4;^__]F#Q]$``!(BSV1D```Z/3T__](B065D```28G$2(7`
M#X5=____2(T]0B(``#'`Z+/B__\/'P"`>`$`#X0%_?__Z?G\__^02(L%49``
M`(L]PW\``$R+($B+0Q!(BRCHQ-___TR)YDB)[^@)[/__Z9O^__^+/9Y_``#H
MJ=___TB)[DB)Q^@.XO__Z1?^___H%.+__XG!2(L%`Y```$R)XDB-/?$A``!(
MBS`QP.@WXO__#Q^``````%5(B?U32(/L".@2\/__#[802(G#A-)T&@\?A```
M````2(/``8#Z+P^V$$@/1-B$TG7N,<#HE_+__TB%[70DA<!T((!]``!T&KD$
M````2(T]6B```$B)WO.F#Y?`'`"$P'0'2(/$"%M=PTB#Q`A(B>];7>E9Z?__
M9@\?A```````05=,C4\X059!54%455-(@>R8`@``9$B+!"4H````2(F$)(@"
M```QP$B)XDR-E"2`````28G09BX/'X0``````$&+`4F+,4F#P!!)@\$(#\B)
MP$B)\4F)0/!(B?!(P>D@2,'H*$C![C@E`/\``$@)\$B)SDC!X0A(P>88@>$`
M`/\`B?9("?!("<A)B4#X33G0=:Y(C;(``@``#Q^``````$B+0FA(,T)`2(/"
M"$@S0@A(,T+X2(T,`$C!Z!]("<B#X/](B4)X2#GR==5,BP=,BT\02(M?($R+
M5QA,B<!,B<)(BW0D"$R+="082,'J&TC!X`5("=`#!"1)C:PRF7F"6HV4&)EY
M@EI,B<A,B<-,,=!((T<(2,'C'DPQT$2-)`)(BU<(2(M'"$R)YDC!XAY(P>@"
M2`G03(G*2,'N&XG!2#'*3"'"3#'*2`'J3(GE2,'E!4@)]4@!U4R)PDC!Z@)!
MB>U("=-(BU0D$$@QV$&)VTPAX$F-E!&9>8):2#'(2HV,,9EY@EI(C3002(GJ
M2,'M&TBXX/___Q\```!(P>(%@^4?2"'"2`GJ2`'R3(GF2<'L`DC!YAZ)U4P)
MYD@Q\T&)]$PAZTPQVT@!RTB)T4C!ZAM(P>$%@^(?2"'!2`G*3(GI2<'M`DC!
MX1Y(`=I,">E,BVPD((G32#'.08G.2"'N3XV<*YEY@EI,,>9,`=Y)B=-(P>H;
M2<'C!8/B'TDAPTD)TTB+5"0H20'S2(GN2,'M`DC!YAY)C904F7F"6D6)W4@)
M[D@Q\8GU2"'93#'Q2`'*3(G92,'A!4@AP4G!ZQM!@^,?3`G93(M<)#!(`=%(
MB=I(P>L"2,'B'D^-G!Z9>8):08G,2`G:2#'6B=-,(>Y(,>Y)`?-(B<Y(P>D;
M2,'F!8/A'T@AQD@)SDB+3"0X3`'>38GK2<'M`DG!XQY(C8P-F7F"6D&)]DT)
MZTPQVD6)W4PAXD@QVD@!T4B)\DC![AM(P>(%@^8?2"'"2`GR2(MT)$!(`<I,
MB>%(P>$>2<'L`DB-M#.9>8):B=5,">%),<M!B<Q-(?--,>M,`=Y)B=-(P>H;
M2<'C!8/B'TDAPTD)TTB+5"1(20'S3(GV2<'N`DC!YAY)C905F7F"6D2)VTP)
M]D@Q\4&)]D@AZ4PQX4@!RDR)V4G!ZQM(P>$%08/C'T@AP4P)V4R+7"102`'1
M2(GJ2,'M`DC!XAY/C9P<F7F"6D&)S4@)ZD@QUHG52"'>3#'V20'S2(G.2,'F
M!4C!Z1M((<:#X1]("<Y(BTPD6$P!WDF)VTC!ZP))P>,>28V,#IEY@EI!B?1)
M"=M,,=I$B=M,(>I(,>I(`=%(B?)(P>X;2,'B!8/F'T@APD@)\DB+="1@2`'*
M3(GI2<'M`DC!X1Y(C;0UF7F"6D&)UDP)Z4DQRT&)S4TAXTDQVTP!WDF)TTC!
MZAM)P>,%@^(?22'#20G32(M4)&A)`?-,B>9(P>8>2<'L`DB-E!.9>8):1(G=
M3`GF2#'Q08GT3"'Q3#'I2`'*3(G92<'K&TC!X05!@^,?2"'!3`G93(M<)'!(
M`=%,B?))P>X"2,'B'D^-G!V9>8):B<M,"?)(,=9!B=9((>Y,,>9)`?-(B<Y(
MP>D;2,'F!8/A'T@AQD@)SDB+3"1X3`'>28GK2,'M`DG!XQY)C8P,F7F"6D&)
M]4D)ZTPQVD2)W4@AVDPQ\D@!T4B)\DC![AM(P>(%@^8?2"'"2`GR2(NT)(``
M``!(`<I(B=E(P>L"2,'A'DF-M#:9>8):08G42`G923'+B<M-(>M),>M,`=Y)
MB=-(P>H;2<'C!8/B'TDAPTD)TTB+E"2(````20'S3(GN2<'M`DC!YAY(C905
MF7F"6D6)WDP)[D@Q\4&)]4PAX4@QV4@!RDR)V4G!ZQM(P>$%08/C'T@AP4P)
MV4@!T4R)XDG![`)(P>(>B<U,">),BZ0DD````$@QUD&)TTPA]DJ-G".9>8):
M3#'N2`'>2(G+2,'I&TC!XP6#X1]((<-("=E,B?-)P>X"2,'C'HG)3`GS2`'.
M2(N,))@```!(,=I!B?1((>I)C8P-F7F"6DV)Y4PQVDG![1M(`<I,B>%(P>$%
M3`GIB<E(`<I(B>E(P>T"2,'A'D&)U4@)Z4B)W8G;2#'-,>Y(BZPDH````$V-
MG"NAZ]EN3(GM20'S3(GN2,'F!4C![1M(`YPDJ````$@)[HGV3`'>38GC2<'L
M`DG!XQZ)]4T)XTF)S(G)2`.,)+````!-,=Q$,>),C:03H>O9;DB)ZDB)ZTC!
MZQM(P>(%2`G:B=))C1P43(GJ2<'M`DC!XAY!B=Q,">I-B=U%B=M,`YPDN```
M`$DQU40Q[DV)Y4B-M#&AZ]EN3(GA2<'M&TC!X05,">F)R4@!\4B)[DC![0)(
MP>8>08G-2`GN2(G5B=)(,?4QZTR)[4F-G!NAZ]EN38GK2,'M&TG!XP5)">M%
MB=M)`=M,B>-(P>,>2<'L`D2)W4@#E"3`````3`GC28GTB?9(`[0DR````$DQ
MW$0QX4F)[$B-C`JAZ]EN2(GJ2<'L&TC!X@5,">*)TD@!RDR)Z4G![0)(P>$>
M08G43`GI28G=B=M(`YPDT````$DQS44QZTV)Y4Z-G!ZAZ]EN3(GF2<'M&TC!
MY@5,">Z)]DP!WDF)ZTC![0))P>,>08GU20GK2(G-B<E,,=TQZDB-K!.AZ]EN
M3(GJ3(GK2,'K&TC!X@5("=J)TDB-7!4`3(GB2<'L`DC!XAZ)W4P)XDV)W$@#
MC"38````18G;23'43`.<).````!$,>9)B>Q(C;0QH>O9;DB)Z4G![!M(P>$%
M3`GAB<E(`?%,B>Y)P>T"2,'F'D&)S$P)[DF)U8G22`.4).@```!),?5$,>M-
MB>5)C9P;H>O9;DV)XTG![1M)P>,%30GK18G;20';2(GK2,'M`DC!XQY%B=U(
M">M(B?6)]D@#M"3P````2#'=,>E,B>U(C8P*H>O9;DR)ZDC![1M(P>(%2`GJ
MB=)(`<I,B>%)P>P"2,'A'HG53`GA28G<B=M),<Q%,>-)B>Q(`YPD^````$Z-
MG!ZAZ]EN2(GN2<'L&TC!Y@5,">:)]DP!WDV)ZTG![0))P>,>08GT30GK28G-
MB<E(`XPD``$``$TQW40QZDR-K!.AZ]EN3(GB3(GC2,'K&TC!X@5("=J)TDF-
M7!4`2(GJ2,'M`DC!XAY!B=U(">I,B=U%B=M,`YPD"`$``$@QU3'N3(GM2(VT
M,:'KV6Y,B>E(P>T;2,'A!4@)Z8G)2`'Q3(GF2<'L`DC!YAZ)S4P)YDF)U(G2
M23'T1#'C28GL28V<&Z'KV6Y)B>M)P>P;2<'C!4T)XT@#E"00`0``18G;20';
M3(GK2<'M`DC!XQY%B=Q,">M)B?6)]D@#M"08`0``23'=1#'I38GE2(V,"J'K
MV6Y,B>))P>T;2,'B!4P)ZHG22`'*2(GI2,'M`DC!X1Y!B=5(">E(B=V)VT@#
MG"0@`0``2#'-03'K3(GM3HV<'J'KV6Y,B>Y(P>T;2,'F!4@)[HGV3`'>38GC
M2<'L`DG!XQZ)]4T)XTF)S(G)33'<1#'B3(VD$Z'KV6Y(B>I(B>M(P>L;2,'B
M!4@)VHG228T<%$R)ZDC!XAY)P>T"08G<2`.,)"@!``!,">I-B=U%B=M,`YPD
M,`$``$DQU40Q[DV)Y4B-M#&AZ]EN3(GA2<'M&TC!X05,">F)R4@!\4B)[DC!
M[0)(P>8>08G/2`GN2(G538G]B=)(,?5)P>4%2`.4)#@!```QZTF-G!NAZ]EN
M38G[2<'K&TT)ZTZ-+!M,B>-)P>P"28GS2,'C'D2)[8GV3`GC23';08G>1#'9
M38GK2<'M&TG!XP5(C90*H>O9;D&#Y1],B?E(P>$>22'#2<'O`DT)ZTF)W4D!
MTTP)^;K<O!N/08G/20G-18G<3"'[22'M20G=2(N<)$`!``!(`=-(`=Y)`?5,
MB=Y)P>L;2,'F!4&#XQ]((<9,"=Y,`>Y)B>U(P>T"2<'E'HGS20GM3`GI38GK
M1(GM32'[3"'A3`G93(N<)$@!``!)`=--`?--B>9)P>P"20'+2(GQ2,'N&TC!
MX06#YA])P>8>2"'!2`GQ3(GN3`'930GF18GT3`GV08G+2"'>32'E20GU2(NT
M)%`!``!(`=9,`?Y)B=](P>L"20'U2(G.2<'G'DC!Y@5(P>D;20G?2"'&@^$?
M30G^1(G[2`G.3(GY32'>3"'A3`'N20G.2(N,)%@!``!!B?5(`=%(`>E)`<Y(
MB?%(P>X;2,'A!8/F'T@AP4@)\4R)_DP!\4V)WDG!ZP))P>8>B<U-"=Y%B?-,
M"?9,(>Y-(=])"?=(B[0D8`$``$@!UDP!YDD!]TB)SDC!Z1M(P>8%@^$?2"'&
M2`G.3`'^38GO2<'M`DG!YQY!B?1-">]-"?Y,B?E%B?U,(=E)(>Y)"<Y(BXPD
M:`$``$@!T4@!V4D!SDB)\4C![AM(P>$%@^8?2"'!2`GQ3(G^3`'Q28GN2,'M
M`DG!YAZ)RTD)[D2)]4P)]DPAYDDA[TD)]TB+M"1P`0``2`'63`'>20'W2(G.
M2,'I&TC!Y@6#X1]((<9("<Y,`?Y-B>=)P>P"2<'G'D&)\TT)YTT)_DR)^46)
M_$@AZ4DAWDD)SDB+C"1X`0``2`'13`'I28G=2,'K`DD!SDB)\4C![AM(P>$%
M@^8?2<'E'D@AP4@)\4R)_DP!\4D)W42)ZTP)[D&)SDPAWDDAWTD)]TB+M"2`
M`0``2`'62`'N20'W2(G.2,'I&TC!Y@6#X1]((<9("<Y,`?Y-B=])P>L"2<'G
M'HGU30G?30G]3(GY18G[2"'932'U20G-2(N,)(@!``!(`=%,`>%)`<U(B?%(
MP>X;2,'A!8/F'T@AP4@)\4R)_DP!Z4V)]4G![@))P>4>08G,30GU18GN3`GN
M2"'N32'W20GW2(NT))`!``!(`=9(`=Y)`?=(B<Y(P>D;2,'F!8/A'T@AQD@)
MSDP!_DF)[TC![0))P><>B?-)">]-"?U,B?E$B?U,(?%-(>5)"<U(BXPDF`$`
M`$@!T4P!V4D!S4B)\4C![AM(P>$%@^8?2"'!2`GQ3(G^3`'I38GE2<'L`DG!
MY1Y!B<M-">5%B>Q,">Y((=Y-(>=)"?=(B[0DH`$``$@!UDP!]DD!]TB)SDC!
MZ1M(P>8%@^$?2"'&2`G.3`'^28G?2,'K`DG!YQY!B?9)"=]-"?U,B?E$B?M,
M(>%-(=U)"<U(BXPDJ`$``$@!T4@!Z4R)W4G!ZP))`<U(B?%(P>X;2,'A!8/F
M'TC!Y1Y((<%("?%,B?Y,`>E,"=U!B>M(">Y!B<U,(?9-(=])"?=(B[0DL`$`
M`$@!UDP!YDD!]TB)SDC!Z1M(P>8%@^$?2"'&2`G.3`'^38GW2<'N`DG!YQY!
MB?1-"?=,"?U,B?E%B?Y,(=E,(>U("<U(BXPDN`$``$@!T4@!V4R)ZTG![0)(
M`<U(B?%(P>X;2,'A!8/F'TC!XQY((<%("?%,B?Y(`>E,">M!B=U("=Z)S4PA
MYDTA[TD)]TB+M"3``0``2`'63`'>38GC2<'L`DD!]TB)SDG!XQY(P>8%2,'I
M&TT)XT@AQH/A'TP)VT6)W$@)SDR)V4@AZTPAZ4P!_D@)RTB+C"3(`0``08GW
M2`'13`'Q38G>2`'+2(GQ2,'N&TC!X06#YA]((<%("?%(`=E(B>M(P>T"2,'C
M'HG.2`G=B>M)">Y-(?Y)(=M-"?-,B[0DT`$``$D!UD@#E"38`0``30'U3`'B
M30'=28G+2,'I&TG!XP6#X1])(<-,"=F)R4P!Z4V)_4G![P))P>4>08G+30GO
M38G<3`G]38G^2<'L&T6)_4DAWD@A]4P)]4R+M"3@`0``2`'53(G:2,'B!4P)
MXHG22`'52(GR2,'N`DC!XAY!B>Q("=:ZUL%BRDDQ]T0Q^4D!UDP!\TV)YD@!
MRTR)X4G![AM(P>$%3`GQB<E(`<M,B=E)P>L"2,'A'D&)WDD)RTB)\8GV3#'9
M,<U(BXPDZ`$``$@!T4P!Z4V)]4@!S4R)\4G![1M(P>$%3`GIB<E(`<U,B>%)
MP>P"2,'A'D&)[4D)S$B+C"3P`0``2`'12`'Q3(G>18G;3#'F,=Y,B>M(`<Y,
MB>E(P>L;2,'A!4@)V8G)2`'.3(GQ2,'A'DG![@*)\TD)SDB+C"3X`0``2`'1
M3`'938GC18GD33'S1#'=28G;2`'-2(G92<'K&TC!X05,"=E,BYPD``(``(G)
M2`'-3(GI20'32<'M`DC!X1Y-`>--B?1!B>],">E%B?9),<Q$,>9-B?Q)`?-,
MB?Y)P>P;2,'F!4P)YD&)]$B)WDC!ZP)(P>8>30'<28G+B<E("?-(B[0D"`(`
M`$6)Y4DQVT@!UD0QW4V)ZTP!]D@!]4R)[DC!Y@5)P>L;3`G>38G[2<'O`HGV
M2<'C'D@!]4B+M"00`@``30G[08GN2`'62`'Q2(G>B=M,,=Y!,?1,B?9)`<Q,
MB?%(P>X;2,'A!4@)\8G)20',3(GI2<'M`DC!X1Y%B>=)"<U(BXPD&`(``$R)
M_DC![AM(`=%(`=E,B=M%B=M,,>LQZT@!RTR)^4C!X05("?%,B?9)P>X"B<E(
MP>8>2`'+2(N,)"`"``!,"?:)W4@!T4P!V4V)ZT6)[4DQ\T4QW$F)ZTD!S$B)
MZ4G!ZQM(P>$%3`G928GSB?:)R4D!S$R)^4G![P)(P>$>18GF20G/2(N,)"@"
M``!-,?M(`=%$,=M-B?-,`>E)P>L;2`'+3(GQ2,'A!4P)V4R+G"0P`@``B<E(
M`<M(B>E(P>T"20'32,'A'D&)W4P!WD@)Z4R)_4V)ZT6)_T@QS4G!ZQM$,>5(
M`?5,B>Y(P>8%3`G>28G+B<F)]D@!]4R)]DC!YAY)P>X"08GL20GV2(NT)#@"
M``!-,?-(`=9$,=M-B>-,`?Y)P>L;2`'S3(GF2,'F!4P)WDV)ZTG![0*)]DG!
MXQY(`?-(B[0D0`(``$T)ZT&)WT@!UD@!\4R)]D6)]DPQWC'U3(G^2`'-3(GY
M2,'N&TC!X05("?%,B=Y%B=N)R4@!S4R)X4G![`)(P>$>08GM20G,2(N,)$@"
M``!,,>9(`=$Q\TR)[DP!\4@!RTR)Z4C!X05(P>X;2`GQ3(G^2<'O`HG)2,'F
M'D@!RTB+C"10`@``3`G^08G>2`'13`'938GC18GD23'S03'K3(GU20'+3(GQ
M2,'M&TC!X05(">F)R4D!RTR)Z4G![0)(P>$>1(G=20G-2(N,)%@"``!(`=%,
M`>%)B?2)]DTQ[$0QXTF)[$@!RTB)Z4G![!M(P>$%3`GAB<E(`<M,B?%)P>X"
M2,'A'D&)W$P)\4R+M"1@`@``20'63`'V38GN18GM23'.13'S38GF3`'>38GC
M2<'N&TG!XP5-"?-)B>Y(P>T"2<'F'D6)VTP)]4R+M"1H`@``3`'>08GS20'6
M30'U28G.B<E),>Y$,?--B=Y,`>M-B=U)P>X;2<'E!4T)]4V)YDG![`))P>8>
M18GM30GT3(NT)'`"``!,`>M!B=U)`=9,`?%)B>Z)[4TQYD0Q]DV)[D@!SDR)
MZ4G![AM(P>$%3`GQ2`'Q3(G>2,'F'DG!ZP)(`Y0D>`(``$D)\TR)YDP!PD0#
M9R!,,=Y(`>I%`=I,B6<@,?-(B<Y,B5<82,'F!4@!VD@A\$B)S@-/"$C![AM(
MB4\(@^8?2`GP`=!(B0=,B>A)P>T"2,'@'DD)Q44!Z4R)3Q!(BX0DB`(``&1(
M,P0E*````'422('$F`(``%M=05Q!74%>05_#Z*S*__]F9BX/'X0``````)!(
M@^P(OX````#HTLC__[J)J\WON?[<NIB^\.'2PTC'``$C16=(B5`(2(E($$C'
M0!AV5#(02(EP($C'0"@`````2,=`,`````#'0'@`````2(/$",-F9BX/'X0`
M`````)!!5TACPD%628G&055!5$F)_%5(C6\X4TB)\TB#[`A(BW<H2(M7,(T,
MQD@Y\4B)3RA(@](`2,'H'4@!T$B)1S!(8T=XA<`/A>T```!!@_X_#XXK`0``
M08/N0$6)]T'![P9%B?U)@\4!2<'E!DD!W6:0\P]O`TR)YTB#PT`/$44`\P]O
M2]`/$4T0\P]O4^`/$54@\P]O6_`/$5TPZ#'H__],.>MUS$'!YP9%*?Y)8\9(
M@_@(<EQ)BU4`28E4)#A)BU0%^$B)5`7X2(U5"$B#XOA(*=5)*>U(`<5(@^7X
M2(/]"'(82(/E^#'`28M,!0!(B0P"2(/`"$@YZ'+N18ET)'A(@\0(6UU!7$%=
M05Y!7\-FD*@$=71(A<!TX4$/ME4`08A4)#BH`G3300^W5`7^9HE4!?[KQ@\?
M0`!!O4````!(C7P%`$B)WD$IQ44Y[D4/3NY-8_U,B?KHQ<G__T&+1"1X1`'H
M08E$)'B#^$!UDDR)YT4I[DP!^^A5Y___Z<O^__])B=WI(____T&+50!!B50D
M.$&+5`7\B50%_.E;____D$%63(UV.$%505152(GU4TB+1BA(B?M$BV8H1(MN
M,$C!Z`.#X#]!#\Q!#\V-2`%(F,9$!CB`2&/!3`'P@_DX#XXL`0``ND`````I
MRHG1=`\QTHG6@\(!Q@0P`#G*<O-(B>_HRN;__V8/[\`/$44X2<=&,`````!!
M#Q%&$$$/$48@1(EM<$B)[T2)973HH.;__TB+10!(B>](P>@8B`-(BT4`2,'H
M$(A#`4B+10!(P>@(B$,"2(M%`(A#`TB+10A(P>@8B$,$2(M%"$C!Z!"(0P5(
MBT4(2,'H"(A#!DB+10B(0P=(BT402,'H&(A#"$B+11!(P>@0B$,)2(M%$$C!
MZ`B(0PI(BT40B$,+2(M%&$C!Z!B(0PQ(BT482,'H$(A##4B+11A(P>@(B$,.
M2(M%&(A##TB+12!(P>@8B$,02(M%($C!Z!"(0Q%(BT4@2,'H"(A#$DB+12"(
M0Q-;74%<05U!7ND9QO__9@\?A```````NC@````Q_RG*@_H(<D*)T4C'````
M``!(QT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(#X+7_O__@^+X,<")QH/`
M"$B)/#$YT'+SZ<#^___VP@1U(X72#X2S_O__Q@``]L("#X2G_O__,<EFB4P0
M_NF;_O__#Q\`QP``````QT00_`````#IA?[__P\?1```05=,C3V?7P``059)
MB=9!54F)]4%408G\54B-+9!?``!33"G]2(/L".C#P___2,']`W0;,=L/'P!,
MB?),B>Y$B>=!_Q3?2(/#`4@YW77J2(/$"%M=05Q!74%>05_##Q\`PV8N#Q^$
M```````/'T0``$B+#8%C``#I-,3__TB#[`A(@\0(PP``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P
M,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E
M<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2
M.CI086-K97(Z.E9%4E-)3TX`,2XP-#D`+64`+2T`````````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!
M4E]-04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF
M:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY
M("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G
M.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B
M86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M
M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?
M34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D[
M"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD[
M"GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G
M/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68[
M"FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T
M("H@,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S
M:7IE*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ
M92`E("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@
M)&T["GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE
M.PI]"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:RA?1D@L("1M86=I
M8U]P;W,L(#`I.PIR96%D*%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG
M=&@H)%!!4E]-04=)0RDI.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("10
M05)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*
M)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P
M;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(
M+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH
M(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M
M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,
M24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN
M86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U
M:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I
M;G0@)&9H("1I;F9O+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L
M("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2([
M"F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*
M=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES
M="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE
M(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@
M>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N
M;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID
M96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N
M;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L
M;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@
M)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E
M<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H
M)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`
M05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B
M.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D
M:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!
M4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD[
M"F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q
M(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/
M.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W
M-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D
M9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@
M,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@
M;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*
M;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE
M<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B
M:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O
M;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<
M15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R
M*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<
M6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE
M;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER
M+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J
M;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL
M93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO
M<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D[
M"GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B
M1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT
M*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P
M96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH
M97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!
M1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I[
M"FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M
M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/
M.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2`O
M+R`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD
M9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``````````<&5R
M;'AS:2YC`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M`1L#.P0!```?````H(+__U`!``!0AO__>`$``&"&___L!0``<(C__R`!``!@
MB?__D`$``#"*___<`0``P(K__P@"```0C?__5`(``'".__^8`@```(___[P"
M``#@C___``,``!"0__\8`P``8)#__S`#```@D?__9`,``#"1__]X`P``,)/_
M_]@#``!@D___[`,``$"4__\<!```$);__T`$``"0EO__7`0``+"6__]T!```
MD)?__[0$``!@G___;`4``$"C__^X!0``P*/__Q@&``"0NO__:`8``/"Z__^`
M!@``D+S__\P&``"0OO__$`<``/"^__]8!P```+___W`'````````%```````
M```!>E(``7@0`1L,!PB0`0<0%````!P```!(A___*P``````````````%```
M```````!>E(``7@0`1L,!PB0`0``)````!P```!(@?__L`,````.$$8.&$H/
M"W<(@``_&CLJ,R0B`````!0```!$````T(3__P@``````````````$@```!<
M````R(?__\T`````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y`
M`FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)"P`H````J````$R(__^$`````$$.
M$(8"00X8@P-'#C`"<PH.&$$.$$$."$$+`$@```#4````L(C__TD"````0@X0
MCP)"#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@`Q<!"@XX00XP00XH0@X@
M0@X80@X00@X(2PM`````(`$``+2*__]<`0```$(.$(X"0@X8C0-"#B",!$$.
M*(8%00XP@P9'#M`!?@H.,$$.*$$.($(.&$(.$$(."$L+`"````!D`0``T(O_
M_XL`````00X0A@)2#K`!`G$*#A!!#@A!"T````"(`0``/(S__]P`````0@X0
MCP)'#AB.`T(.((T$0@XHC`5$#C"&!E$.P"`"@@H.,$$.*$(.($(.&$(.$$(.
M"$,+%````,P!``#8C/__,`````!$#A!6#@@`%````.0!``#PC/__20````!$
M#A`"0`X(,````/P!```HC?__OP````!"#A",`D$.&(8#00X@@P1'#L!``J<*
M#B!$#AA!#A!"#@A!"Q`````P`@``M(W__P4`````````7````$0"``"PC?__
M\@$```!"#A"/`D(.&(X#10X@C01"#BB,!4L.,(8&00XX@P='#O`A`F0*#CA!
M#C!!#BA"#B!"#AA"#A!"#@A$"P*D#O@A20Z`(F(.^"%!#O`A````$````*0"
M``!0C___)0`````````L````N`(``&R/___<`````$H.$(8"`F$*Q@X(10L"
M0`H."$@+2`K&#@A%"TL.",8@````Z`(``!R0___.`0```$$.$(8"30Y0`V,!
M"@X000X(1@L8````#`,``,B1__]T`````$0.(&\*#@A%"P``%````"@#```L
MDO__'0````!$#A!8#@@`/````$`#```TDO__W@````!"#A",`D$.&(8#2PX@
M@P1$#C`"3`H.($$.&$$.$$(."$8+;@XX20Y`=`XX00XP`+0```"``P``U)+_
M_\4'````0@X0CP)"#AB.`T(.((T$3`XHC`5!#C"&!D$..(,'1P[`@P(#_@$.
MR(,"80[0@P)?#LB#`D(.P(,"`G@*#CA$#C!!#BA"#B!"#AA"#A!"#@A("P."
M`0[(@P))#M"#`F`.R(,"00[`@P)B#LB#`D4.T(,"3@[8@P)-#N"#`DL.P(,"
M`P$"#LB#`D0.T(,":`[(@P)!#L"#`@*K"@[(@P)!#M"#`D4+``!(````.`0`
M`.R9___9`P```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.4`/4
M`@H..$$.,$$.*$(.($(.&$(.$$(."$0+,````(0$``"`G?__=P````!!#A"&
M`D0.&(,#1`X@`ET*#AA!#A!!#@A!"T0.&$0.$$$.""@```"X!```;(#__P0"
M````0@X0C`)!#AB&`T0.4`.C`0H.&$0.$$(."$$+3````.0$``"@G?__Q!8`
M``!"#A"/`D8.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`Y\6"@XX00XP
M00XH0@X@0@X80@X00@X(00L````4````-`4``""T__]4`````$0.$`)/#@A(
M````3`4``&BT__^?`0```$(.$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#
M!T<.0`+E"@XX00XP00XH0@X@0@X80@X00@X(0PL`0````)@%``"\M?__^P$`
M``!"#A".`D8.&(T#0@X@C`1!#BB&!40.,(,&`TP!"@XH00X@0@X80@X00@X(
M3@L```````!$````W`4``'BW__]=`````$(.$(\"20X8C@-%#B"-!$4.*(P%
M1`XPA@9(#CB#!T<.0&H..$$.,$$.*$(.($(.&$(.$$(."``4````)`8``)"W
M__\!```````````````0````/`8``(BW__\,````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````-`F````
M````D"8````````!``````````$``````````0````````"\`0````````$`
M````````"P(````````,```````````@````````#0````````",7```````
M`!D`````````N+L````````;``````````@`````````&@````````#`NP``
M`````!P`````````"`````````#U_O]O``````@#````````!0````````!H
M#0````````8`````````"`0````````*`````````,L$````````"P``````
M```8`````````!4````````````````````#`````````-B]`````````@``
M``````!P!0```````!0`````````!P`````````7```````````5````````
M!P````````"`$P````````@`````````@`$````````)`````````!@`````
M````'@`````````(`````````/O__V\``````0``"`````#^__]O```````3
M````````____;P`````"`````````/#__V\`````-!(```````#Y__]O````
M``0`````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#(
MNP`````````````````````````````V(````````$8@````````5B``````
M``!F(````````'8@````````AB````````"6(````````*8@````````MB``
M``````#&(````````-8@````````YB````````#V(`````````8A````````
M%B$````````F(0```````#8A````````1B$```````!6(0```````&8A````
M````=B$```````"&(0```````)8A````````IB$```````"V(0```````,8A
M````````UB$```````#F(0```````/8A````````!B(````````6(@``````
M`"8B````````-B(```````!&(@```````%8B````````9B(```````!V(@``
M`````(8B````````EB(```````"F(@```````+8B````````QB(```````#6
M(@```````.8B````````]B(````````&(P```````!8C````````)B,`````
M```V(P```````$8C````````5B,```````!F(P```````'8C````````AB,`
M``````"6(P```````*8C````````MB,```````#&(P``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#H8@```````$=#
M0SH@*$1E8FEA;B`Y+C(N,2TR-2D@.2XR+C$@,C`R,#`Q,C,``"YS:'-T<G1A
M8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG
M;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R
M<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G!L="YG;W0`+G1E
M>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM
M96YT````````````````````````````````````````````````````````
M````````````````````````````````````"P````$````"`````````*@"
M````````J`(````````<`````````````````````0``````````````````
M`!,````'`````@````````#$`@```````,0"````````)```````````````
M``````0````````````````````F````!P````(`````````Z`(```````#H
M`@```````"`````````````````````$````````````````````-````/;_
M_V\"``````````@#````````"`,```````#\``````````4`````````"```
M`````````````````#X````+`````@`````````(!`````````@$````````
M8`D````````&`````0````@`````````&`````````!&`````P````(`````
M````:`T```````!H#0```````,L$```````````````````!````````````
M````````3@```/___V\"`````````#02````````-!(```````#(````````
M``4``````````@`````````"`````````%L```#^__]O`@``````````$P``
M```````3````````@``````````&`````@````@```````````````````!J
M````!`````(`````````@!,```````"`$P```````(`!````````!0``````
M```(`````````!@`````````=`````0```!"```````````5`````````!4`
M``````!P!0````````4````6````"``````````8`````````'X````!````
M!@``````````(``````````@````````%P````````````````````0`````
M``````````````!Y`````0````8`````````("`````````@(````````+`#
M```````````````````0`````````!``````````A`````$````&````````
M`-`C````````T",````````(````````````````````"``````````(````
M`````(T````!````!@````````#@(P```````.`C````````K#@`````````
M`````````!````````````````````"3`````0````8`````````C%P`````
M``",7`````````D````````````````````$````````````````````F0``
M``$````"``````````!@`````````&````````"`/0``````````````````
M$````````````````````*$````!`````@````````"`G0```````("=````
M````!`$```````````````````0```````````````````"O`````0````(`
M````````B)X```````"(G@```````(`&```````````````````(````````
M````````````N0````X````#`````````+B[````````N*L````````(````
M````````````````"``````````(`````````,4````/`````P````````#`
MNP```````,"K````````"`````````````````````@`````````"```````
M``#1````!@````,`````````R+L```````#(JP```````!`"````````!@``
M```````(`````````!``````````B`````$````#`````````-B]````````
MV*T````````H`@``````````````````"``````````(`````````-H````!
M`````P``````````P`````````"P````````(`````````````````````@`
M``````````````````#@````"`````,`````````(,`````````@L```````
M`*@0```````````````````@````````````````````Y0````$````P````
M````````````````(+`````````F`````````````````````0`````````!
M``````````$````#`````````````````````````$:P````````[@``````
:``````````````$`````````````````````
